# Tracetool Api for Python

Python file ([tracetool.py](/Python/Src/tracetool/tracetool.py "tracetool.py"))
is included in the Python/Src/tracetool folder.

The library is compatible with Python 2, Python 3, and Iron Python (.NET). \
The library was also tested under Blender

Sample code

``` Python
>>> from tracetool import ttrace
>>> ttrace.debug.send ("hello Python")
```

Refer to github project <https://github.com/capslock66/Tracetool> for full documentation